اطلاعات شرکت سرو

##### شرکت مدیریت فناوری بورس تهران

###### مرکز پردازش اطلاعات مالی ایران

## اطلاعات شرکت سرو

1. صفحه اصلی
2. اطلاعات شرکت سرو

- اطلاعات بازار
- قیمت
- نمودار ها
- تاریخچه قیمت

- اطلاعات شرکت
- معرفی شرکت

- اطلاعات مالی
- اقلام ترازنامه
- اقلام سود و زیان
- تاریخچه در آمد هر سهم

- پردازش اطلاعات مالی
- روند سود سازی
- نسبت های مالی
- سود واقعی در یک نگاه
- پیش بینی سود در یک نگاه

- شرکت های هم گروه
- مقایسه مالی
- مقایسه قیمت

#### نام نماد :

سرو

#### نام شرکت :

صندوق سرمایه گذاری سرو سودمند مدبران

#### مدیر عامل:

رضا درخشان فر

#### تلفن:

021-26231274

#### فکس:

#### آدرس:

#### وب سایت:

#### ایمیل:

#### سال مالی:

09/30

#### موضوع فعالیت:

موضوع فعالیت صندوق، سرمایه‌گذاری در انواع اوراق بهادار از جمله سهام و حق تقدم سهام پذیرفته¬شده در بورس تهران و فرابورس ایران، گواهی سپرده کالایی، اوراق بهادار با درآمد ثابت، سپرده‌ها و گواهی¬های سپردۀ بانکی است.